summaryrefslogtreecommitdiffstats
path: root/examples/rainfall/rainfallchart.h
diff options
context:
space:
mode:
Diffstat (limited to 'examples/rainfall/rainfallchart.h')
-rw-r--r--examples/rainfall/rainfallchart.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/rainfall/rainfallchart.h b/examples/rainfall/rainfallchart.h
index 9c8a3b5f..2c596f5c 100644
--- a/examples/rainfall/rainfallchart.h
+++ b/examples/rainfall/rainfallchart.h
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
** This file is part of the QtDataVis3D module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
@@ -20,9 +20,9 @@
#define RAINFALLCHART_H
#include "variantbardataproxy.h"
-#include <QtDataVis3D/q3dbars.h>
+#include <QtDataVisualization/q3dbars.h>
-using namespace QtDataVis3D;
+using namespace QtDataVisualization;
class RainfallChart : public QObject
{
@@ -4,7 +4,7 @@
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in